package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.RelationalDatabaseServices;

/**
 * 关系型数据库服务Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface RelationalDatabaseServicesMapper 
{
    /**
     * 查询关系型数据库服务
     * 
     * @param id 关系型数据库服务主键
     * @return 关系型数据库服务
     */
    public RelationalDatabaseServices selectRelationalDatabaseServicesById(Integer id);

    /**
     * 查询关系型数据库服务列表
     * 
     * @param relationalDatabaseServices 关系型数据库服务
     * @return 关系型数据库服务集合
     */
    public List<RelationalDatabaseServices> selectRelationalDatabaseServicesList(RelationalDatabaseServices relationalDatabaseServices);

    /**
     * 新增关系型数据库服务
     * 
     * @param relationalDatabaseServices 关系型数据库服务
     * @return 结果
     */
    public int insertRelationalDatabaseServices(RelationalDatabaseServices relationalDatabaseServices);

    /**
     * 修改关系型数据库服务
     * 
     * @param relationalDatabaseServices 关系型数据库服务
     * @return 结果
     */
    public int updateRelationalDatabaseServices(RelationalDatabaseServices relationalDatabaseServices);

    /**
     * 删除关系型数据库服务
     * 
     * @param id 关系型数据库服务主键
     * @return 结果
     */
    public int deleteRelationalDatabaseServicesById(Integer id);

    /**
     * 批量删除关系型数据库服务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRelationalDatabaseServicesByIds(Integer[] ids);
}
